pub unsafe extern "C" fn opj_stream_default_create(
p_is_input: OPJ_BOOL,
) -> *mut opj_stream_tExpand description
Creates an abstract stream. This function does nothing except allocating memory and initializing the abstract stream.
p_is_input— if set to true then the stream will be an input stream, an output stream else.
@return a stream object.